@@ -14,15 +14,17 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
- * DeviceInfoSource.h
+ * iDeviceInfoSource.h
  *
  *  Created on: Mar 12, 2017
- *      Author: steven
+ *  Author: Steven Hessing (steven.hessing@gmail.com)
  */
 
 #ifndef IDEVICEINFOSOURCE_H_
 #define IDEVICEINFOSOURCE_H_
 
+#include <string>
+
 class iDeviceInfoSource {
 	public:
 		virtual int getFileHandle() = 0;
